@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 # electruth: a collection of boolean logic tools
 # Copyright (C) 2010, 2011  Niels Serup
@@ -29,7 +28,7 @@ _operator_names = ('not', 'and', 'or', 'xor', 'nand', 'nor', 'xnor')
 
 _inverted_operator_names = {
     'and': 'nand',
-    'or': 'nor',
+    'or':  'nor',
     'xor': 'xnor'
 }
 
@@ -115,6 +114,7 @@ _raw_aliases = {
     'nand': 'not and',
     'nor': 'not or',
     'xnor': 'not xor',
+    '⊕': 'xor',
     '∨': ' or ',
     '∧': ' and ',
     '¬': ' not '
@@ -125,7 +125,7 @@ class BooleanExpressionError(Exception):
 
 
 def _recursive_show_loop(op):
-    text = '%s(' % op.get_name()
+    text = '{}('.format(op.get_name())
     t_objs = []
     for x in op.objs:
         if x.is_operator:
@@ -156,23 +156,24 @@ def _match_two(a, b):
     else:
         return False
 
-def _recursive_express_loop(op, and_symbol, or_symbol, not_symbol):
+def _recursive_express_loop(op, and_symbol, or_symbol, not_symbol, xor_symbol):
     if not op.is_operator:
         return op.name
     
     if op.func == NOT:
         rec = _recursive_express_loop(
-            op.objs[0], and_symbol, or_symbol, not_symbol)
-        return (not_symbol or '!%s') % rec
+            op.objs[0], and_symbol, or_symbol, not_symbol, xor_symbol)
+        return (not_symbol or '!{}').format(rec)
     text = '('
     t_objs = []
     for x in op.objs:
         t_objs.append(_recursive_express_loop(
             x, and_symbol, or_symbol,
-            not_symbol))
+            not_symbol, xor_symbol))
     opname = op.func == AND and and_symbol or op.func == OR and \
-        or_symbol or op.get_name().upper()
-    text += (' %s ' % opname).join(t_objs)
+        or_symbol or op.func == XOR and xor_symbol or \
+        op.get_name().upper()
+    text += (' {} '.format(opname)).join(t_objs)
     text += ')'
     return text
 
@@ -185,7 +186,7 @@ def _recursive_test_loop(op, **keyvals):
             objs.append(keyvals[x.get_name()])
     return op.func(*objs)
 
-class BooleanBaseObject(object):
+class BooleanBaseObject:
     is_operator=False
     is_variable=False
 
@@ -215,12 +216,12 @@ class BooleanOperator(BooleanBaseObject):
         self.objs = objs
 
     def set_kind(self, kind):
-        if isinstance(kind, basestring):
+        if isinstance(kind, str):
             try:
                 self.func = _translated_operator_types[kind]
             except KeyError:
                 raise BooleanExpressionError(
-                    'operator %s does not exist' % kind)
+                    'operator {} does not exist'.format(kind))
         else:
             self.func = kind
 
@@ -258,28 +259,32 @@ class BooleanOperator(BooleanBaseObject):
             if typ == 'math':
                 _and = '∧'
                 _or = '∨'
-                _not = '¬%s'
+                _not = '¬{}'
+                _xor = '⊕'
             elif typ == 'bool':
                 _and = '·'
                 _or = '+'
-                _not = '%s´'
+                _not = '{}´'
+                _xor = '⊕'
             elif typ == 'latex-bool':
                 _and = '\cdot'
                 _or = '+'
-                _not = '\overline{%s}'
+                _not = '\overline{{{}}}'
+                _xor = '\oplus'
             else:
                 _and = None
                 _or = None
                 _not = None
+                _xor = None
             return _recursive_express_loop(
-                self, _and, _or, _not)
+                self, _and, _or, _not, _xor)
 
     def __str__(self):
         return _recursive_show_loop(self)
 
 def parse_raw_expression(expr, always_return_op=False, simplify=False):
     """Convert a raw expression into an internal format."""
-    for orig, new in _raw_aliases.iteritems():
+    for orig, new in _raw_aliases.items():
         expr = expr.replace(orig, new)
     expr = expr.split()
     complete = _parse_raw_part(expr)
