@@ -1,12 +1,12 @@
 program_name = 'electruth'
 program_description = 'A collection of boolean logic tools'
-version_num = (0, 1, 1)
+version_num = (0, 2, 0)
 version_text = '.'.join(map(str, version_num))
 version_info = '''\
-%s %s
+{} {}
 Copyright (C) 2010, 2011  Niels Serup
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>
 This is free software: you are free to change and redistribute it.
 There is NO WARRANTY, to the extent permitted by law.\
-''' % (program_name, version_text)
+'''.format(program_name, version_text)
 
