@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 # electruth: a collection of boolean logic tools
 # Copyright (C) 2010, 2011  Niels Serup
@@ -46,7 +45,7 @@ class SettingsParser(object):
             self.__dict__[prop] = val
 
     def __init__(self, ok_config_translations={}, **etc):
-        for key, val in basic_config_translations.iteritems():
+        for key, val in basic_config_translations.items():
             ok_config_translations[key] = val
         ok_config_values = set(ok_config_translations.keys())
 
