@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 # electruth: a collection of boolean logic tools
 # Copyright (C) 2010, 2011  Niels Serup
@@ -68,7 +67,7 @@ class Utility(SettingsParser):
             self.error_function(msg, done, color=self.term_color_errors)
 
     def status(self, msg):
-        print ginfo.program_name + ': ' + msg
+        print(ginfo.program_name + ': ' + msg)
 
     def add_expression(self, o_name, expr):
         if self.do_compare:
@@ -77,18 +76,21 @@ class Utility(SettingsParser):
             i = 0
             while name in names:
                 i += 1
-                name = o_name + '_%d' % i
+                name = o_name + '_{}'.format(i)
         else:
             name = o_name
         self.exprs.append((name, o_name, expr))
 
     def add_expressions(self, **exprs):
-        for key, val in exprs.iteritems():
+        for key, val in exprs.items():
             self.add_expression(key, val)
 
     def start(self):
         self.load_inputs()
-        self.exprs.sort()
+        try:
+            self.exprs.sort()
+        except TypeError:
+            self.error('when not comparing, names must differ', True)
         self.print_exprs()
 
     def load_inputs(self):
@@ -119,7 +121,7 @@ class Utility(SettingsParser):
 
     def print_exprs(self):
         if not self.exprs:
-            print 'No expressions given'
+            print('No expressions given')
             return
 
         prevs = []
@@ -128,7 +130,7 @@ class Utility(SettingsParser):
                 i = 1
                 for x in prevs[:-1]:
                     for y in prevs[i:]:
-                        print ' \'-', x[0], 'matches', y[0] + '?', x[2].match(y[2])
+                        print(' \'-', x[0], 'matches', y[0] + '?', x[2].match(y[2]))
                     i += 1
                 print
 
@@ -140,10 +142,9 @@ class Utility(SettingsParser):
                 maybe_compare()
                 prevs = [x]
 
-            print x[0] + ' =', x[2].express(self.express_type)
+            print(x[0] + ' =', x[2].express(self.express_type))
             prev = x
         maybe_compare()
 
     def end(self):
         pass
-
